package fr.unice.reneviergonin.demogesture.images;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.View;

import java.util.ArrayList;

public class Squares extends View {

    ArrayList<MyPolygon> elements ;
    Paint paint = new Paint(Paint.ANTI_ALIAS_FLAG);
    // nombre de polygones par ligne / colonne
    int nb = 5;
    // internal padding
    float marges = 10;
    // echelle
    float scale = 1;
    // coin visible (clipping)
    float clipingX = 0f;
    float clipingY = 0f;

    protected int[] mySize = {500,500};

    {
        paint.setStrokeWidth(3) ;
        // paint.setStyle(Paint.Style.FILL_AND_STROKE);
        paint.setStyle(Paint.Style.STROKE);
        paint.setAntiAlias(true);
    }

    public Squares(Context context) {
        super(context);
    }

    public Squares(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
    }

    public Squares(Context context, AttributeSet attrs) {
        super(context, attrs);
    }

    @Override
    public void onMeasure(int w, int h) {
        super.onMeasure(w, h);
        mySize[0] = getMeasuredWidth()*2;
        mySize[1] = getMeasuredHeight()*2;

        generatePolygons();
        invalidate();
    }


    public void zoomIn() {
        scale = Math.min(scale*2, 16); invalidate();
    }

    public void zoomOut() {
        scale = Math.max(scale/2, 0.125f); invalidate();
    }

    public void setZoom(float z){
        scale = Math.max(Math.min(z*scale, 16), 0.125f); invalidate();
    }

    public void strafingX(float delta) {
        clipingX += delta;
        invalidate();
    }

    public void strafingY(float delta) {
        clipingY += delta;
        invalidate();
    }

    protected void generatePolygons()
    {
        elements = new ArrayList<MyPolygon>();

        // dimension dans laquelle s'inscrit un polygone
        float w = (mySize[0]-marges*2) / (nb*2);
        float h = (mySize[1]-marges*2) / (nb*2);

        // création de tous les polygones
        for(int i = 0; i < nb; i++)
        {
            for(int j = 0; j < nb; j++)
            {
                MyPolygon p = new MyPolygon();
                float dx = w*2*i+marges;
                float dy = h*2*j+marges;
                float delta = 0;
                float delta2 = 0;

                p.addPoint(dx, dy);

                p.addPoint(dx+w/2, dy+delta);
                p.addPoint(dx+w, dy);
                p.addPoint(dx+w-delta2, dy+h/2);

                p.addPoint(dx + w, dy + h);

                p.addPoint(dx+w/2, dy+h-delta);
                p.addPoint(dx, dy+h);
                p.addPoint(dx+delta2, dy+h/2);

                int coul = (i+j)*255/(2*nb);
                p.color = Color.rgb(coul, coul, coul);

                elements.add(p);
            }
        }

    }


    private float tranformX(float x)
    {
        return (x-clipingX+marges)*scale;
    }


    private float tranformY(float y)
    {
        return (y-clipingY+marges)*scale;
    }

    public void onDraw(Canvas g)
    {
        super.onDraw(g);

        for(MyPolygon p :  elements)
        {
            paint.setColor(p.color);
            float [] pts = p.getPoints();
            for(int i = 0; i<pts.length-3; i=i+2)
            {
                g.drawLine(tranformX(pts[i]), tranformY(pts[i+1]), tranformX(pts[i+2]), tranformY(pts[i+3]), paint);
            }
            g.drawLine(tranformX(pts[pts.length-2]), tranformY(pts[pts.length-1]), tranformX(pts[0]), tranformY(pts[1]), paint);
        }

    }



}
